'''
    Class Station
    
    
'''

import configparser
from RPLCD import CharLCD
import xml.etree.cElementTree as ET


#
# Constants

# Text file where the last station index listened is recorded before switch off
LASTSTATION = "lastStation.txt"


class Station:


    def __init__(self, XMLStationListFile, lcd):
        # Input parameters
        #   XMLstationListFile: XML file listing URL and captions of available stations
        #   lcd: lcd object to display informations
        #
        self.lcd = lcd
        # Status of the station (On/Off)
        self.statusIsOn = False
        # Table of captions for displaying the name of stations
        self.captionList = []

        # Load the list of available web stations (URL and caption) 
        # from an XML file, and setup MPC application
    
        # MPC init
        # Clear the tracklist and rebuilt it from configuration file
        os.system("mpc clear")

        # Init parsing of the XML file to extract all the radio stations
        tree = ET.parse(XMLStationListFile)
        root = tree.getroot()
        for child in root:
            # Look for next radio station to add
            if child.tag == "station":
                # Add the station URL to MPC
                url = child.attrib["url"]
                os.system("mpc add " + url)
                # Add the corresponding caption to the list
                newcaption = child.attrib["caption"]
                self.captionList.append(newcaption)
                print("Station " + newcaption + " added")
                
        if len(self.captionList) > 0:
            print("Total of " + str(len(self.captionList)) + " radio stations")
        else:
            print("No station available, quitting application")
            quit()
        
        # Get the latest track listened before last switch off
        # The track index was stored in the file LASTSTATION
        try:
            f = open(LASTSTATION, "r")
            self.current = int(f.read())
            f.close()
            if self.current <= len(self.captionList):
                print("Restored track " + str(self.current) + ": " + self.caption[self.current-1])
            else:
                print("Restored track does not exist")
                self.current = 1
    
        except (OSError, IOError, ValueError):
            self.current = 1
            print ("Error restoring current track");
        


    def play(self):
        #
        # Start playing the station with MPC
        os.system("mpc play " + str(self.current))
        
        # Display the new track and volume level
        # display the radio caption on the first line
        self.lcd.cursor_pos = (0,0)
        trackName = '{:16.16}'.format(self.caption[self.current-1])
        self.lcd.write_string(trackName) 
        # display volume on 2nd line
        self.lcd.cursor_pos = (1,0)
        volumeLevel = '{:16.16}'.format("Volume: " + str(self.volume) + "%")
        self.lcd.write_string(volumeLevel)   


    def stop(self):
        #
        os.system("mpc stop")
        
        # Very simply, store the current station index in a text file
        try:
            f = open(LASTSTATION, "w")
            f.write(str(self.current))
            f.close()
    
        except (OSError, IOError):
            print ("Error saving current track");

    def next(self):
        #
        # Play next station available
        if self.current < len(self.captionList) :
            self.current += 1
            self.play()
        endif

    def previous(self):
        #
        # Play previous station available
        if self.current > 1 :
            self.current -= 1
            self.play()
        endif

    def setVolume(self, volume):
        #
        # Set volume
        if volume < 0:
            self.volume = 0
        if volume > 100:
            self.volume = 100
        os.system("mpc volume " + str(volume))
    
    def incVolume(self):
        #
        # Increase volume by 5%
        if self.volume <= 95:
            self.volume += 5
            self.play()
            
    def decVolume(self):
        #
        # Decrease volume by 5%
        if self.volume >= 5:
            self.volume -= 5
            self.play()
            
            
            
            
            
            
        
        
        
